@@ -124,7 +124,9 @@ class TestFrontend(unittest.TestCase):
                 'page_title',
                 # To be calculated and set
                 'partition_lvm_status',
-                ]
+                # These are "placeholders" for debconfs impromptu notices
+                'ubi_question_dialog', 'question_label',
+            ]
             deb_host_arch = subprocess.Popen(
                 ['dpkg-architecture', '-qDEB_HOST_ARCH'],
                 stdout=subprocess.PIPE,
