@@ -49,7 +49,7 @@ DBusGMainLoop(set_as_default=True)
 
 #in query mode we won't be in X, but import needs to pass
 if 'DISPLAY' in os.environ:
-    from gi.repository import Gtk, Gdk, GObject
+    from gi.repository import Gtk, Gdk, GObject, GLib
     GObject.threads_init()
     from ubiquity import gtkwidgets
 
@@ -262,7 +262,8 @@ class Wizard(BaseFrontend):
               -GtkProgressBar-min-horizontal-bar-height : 10
             }''')
 
-        Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(),
+        Gtk.StyleContext.add_provider_for_screen(
+            Gdk.Screen.get_default(),
             provider, Gtk.STYLE_PROVIDER_PRIORITY_USER)
 
         # load the main interface
@@ -329,7 +330,8 @@ class Wizard(BaseFrontend):
                 border-width: 0px;
                 padding: 0px;
             }''' % bg).encode())
-        Gtk.StyleContext.add_provider_for_screen(Gdk.Screen.get_default(),
+        Gtk.StyleContext.add_provider_for_screen(
+            Gdk.Screen.get_default(),
             provider, Gtk.STYLE_PROVIDER_PRIORITY_USER)
 
         self.stop_debconf()
@@ -341,7 +343,7 @@ class Wizard(BaseFrontend):
         if osextras.find_on_path('casper-a11y-enable'):
             with open('/proc/cmdline') as fp:
                 if ('UBIQUITY_GREETER' in os.environ or self.oem_user_config or
-                   'only-ubiquity' in fp.read()):
+                        'only-ubiquity' in fp.read()):
                     try:
                         from gi.repository import AppIndicator3 as AppIndicator
                         self.indicator = AppIndicator.Indicator.new(
@@ -417,7 +419,7 @@ class Wizard(BaseFrontend):
         """Crash handler."""
 
         if (issubclass(exctype, KeyboardInterrupt) or
-            issubclass(exctype, SystemExit)):
+                issubclass(exctype, SystemExit)):
             return
 
         # Restore the default cursor if we were using a spinning cursor on the
@@ -466,13 +468,12 @@ class Wizard(BaseFrontend):
             sys.exit(1)
 
     def network_change(self, online=False):
-        from gi.repository import GObject
         if not online:
             self.set_online_state(False)
             return
         if self.timeout_id:
-            GObject.source_remove(self.timeout_id)
-        self.timeout_id = GObject.timeout_add(300, self.check_returncode)
+            GLib.source_remove(self.timeout_id)
+        self.timeout_id = GLib.timeout_add(300, self.check_returncode)
 
     def set_online_state(self, state):
         for p in self.pages:
@@ -645,10 +646,10 @@ class Wizard(BaseFrontend):
 
     def a11y_profile_keys(self, window, event):
         if (event.state & Gdk.ModifierType.CONTROL_MASK and
-            event.keyval == Gdk.keyval_from_name('h')):
+                event.keyval == Gdk.keyval_from_name('h')):
             self.a11y_profile_high_contrast_activate()
         elif (event.state & Gdk.ModifierType.CONTROL_MASK and
-              event.keyval == Gdk.keyval_from_name('s')):
+                event.keyval == Gdk.keyval_from_name('s')):
             self.a11y_profile_screen_reader_activate()
 
     def a11y_profile_high_contrast_activate(self, widget=None):
@@ -668,7 +669,7 @@ class Wizard(BaseFrontend):
         os.environ['UBIQUITY_A11Y_PROFILE'] = 'screen-reader'
         if osextras.find_on_path('orca'):
             self.orca_process = subprocess.Popen(
-                ['orca', '-n'], preexec_fn=misc.drop_all_privileges)
+                ['orca'], preexec_fn=misc.drop_all_privileges)
 
     def a11y_profile_keyboard_modifiers_activate(self, widget=None):
         subprocess.call(
@@ -711,12 +712,12 @@ class Wizard(BaseFrontend):
         self.allow_change_step(True)
 
         # Auto-connecting signals with additional parameters does not work.
-        self.grub_new_device_entry.connect('changed', self.grub_verify_loop,
-            self.grub_fail_okbutton)
+        self.grub_new_device_entry.connect(
+            'changed', self.grub_verify_loop, self.grub_fail_okbutton)
 
         if 'UBIQUITY_AUTOMATIC' in os.environ:
-            self.debconf_progress_start(0, self.pageslen,
-                self.get_string('ubiquity/install/checking'))
+            self.debconf_progress_start(
+                0, self.pageslen, self.get_string('ubiquity/install/checking'))
             self.debconf_progress_cancellable(False)
             self.refresh()
 
@@ -731,6 +732,9 @@ class Wizard(BaseFrontend):
             if hasattr(page.ui, 'plugin_skip_page'):
                 if page.ui.plugin_skip_page():
                     skip = True
+            automatic = False
+            if hasattr(page.ui, 'is_automatic'):
+                automatic = page.ui.is_automatic
 
             if not skip and not page.filter_class:
                 # This page is just a UI page
@@ -749,7 +753,7 @@ class Wizard(BaseFrontend):
 
                 if self.dbfilter is not None and self.dbfilter != old_dbfilter:
                     self.allow_change_step(False)
-                    GObject.idle_add(
+                    GLib.idle_add(
                         lambda: self.dbfilter.start(auto_process=True))
 
                 page.controller.dbfilter = self.dbfilter
@@ -762,7 +766,7 @@ class Wizard(BaseFrontend):
                     self.process_step()
                     if not self.stay_on_page:
                         self.pagesindex = self.pagesindex + 1
-                    if 'UBIQUITY_AUTOMATIC' in os.environ:
+                    if automatic:
                         # if no debconf_progress, create another one, set
                         # start to pageindex
                         self.debconf_progress_step(1)
@@ -786,7 +790,7 @@ class Wizard(BaseFrontend):
         elif not (self.get_reboot_seen() or self.get_shutdown_seen()):
             self.live_installer.hide()
             if ('UBIQUITY_ONLY' in os.environ or
-                'UBIQUITY_GREETER' in os.environ):
+                    'UBIQUITY_GREETER' in os.environ):
                 txt = self.get_string('ubiquity/finished_restart_only')
                 self.quit_button.hide()
             else:
@@ -865,8 +869,8 @@ class Wizard(BaseFrontend):
     def customize_installer(self):
         """Initial UI setup."""
 
-        self.live_installer.set_default_icon_from_file(os.path.join(PIXMAPS,
-                                                        'ubiquity.png'))
+        self.live_installer.set_default_icon_from_file(
+            os.path.join(PIXMAPS, 'ubiquity.png'))
         for eventbox in ['title_eventbox', 'progress_eventbox']:
             box = self.builder.get_object(eventbox)
             style = box.get_style_context()
@@ -876,10 +880,11 @@ class Wizard(BaseFrontend):
         from gi.repository import Vte
         self.vte = Vte.Terminal()
         self.install_details_sw.add(self.vte)
-        self.vte.fork_command_full(0, None,
-            ['/bin/busybox', 'tail', '-f', '/var/log/installer/debug',
-                              '-f', '/var/log/syslog', '-q'],
-            None, 0, None, None)
+        tail_cmd = [
+            '/bin/busybox', 'tail', '-f', '/var/log/installer/debug',
+            '-f', '/var/log/syslog', '-q',
+        ]
+        self.vte.fork_command_full(0, None, tail_cmd, None, 0, None, None)
         self.vte.set_font_from_string("Ubuntu Mono 8")
         self.vte.show()
         # FIXME shrink the window horizontally instead of locking the window
@@ -903,6 +908,7 @@ class Wizard(BaseFrontend):
                 self.get_string('oem_user_config_title'))
             self.live_installer.set_icon_name("preferences-system")
             self.quit.hide()
+            self.back.hide()
 
         if 'UBIQUITY_AUTOMATIC' in os.environ:
             # Hide the notebook until the first page is ready.
@@ -925,7 +931,7 @@ class Wizard(BaseFrontend):
 
         # Parse the slideshow size early to prevent the window from growing
         if (self.oem_user_config and
-            os.path.exists('/usr/share/oem-config-slideshow')):
+                os.path.exists('/usr/share/oem-config-slideshow')):
             self.slideshow = '/usr/share/oem-config-slideshow'
         else:
             self.slideshow = '/usr/share/ubiquity-slideshow'
@@ -951,8 +957,8 @@ class Wizard(BaseFrontend):
 
     def set_window_hints(self, widget):
         if (self.oem_user_config or
-            'UBIQUITY_ONLY' in os.environ or
-            'UBIQUITY_GREETER' in os.environ):
+                'UBIQUITY_ONLY' in os.environ or
+                'UBIQUITY_GREETER' in os.environ):
             f = (Gdk.WMFunction.RESIZE | Gdk.WMFunction.MAXIMIZE |
                  Gdk.WMFunction.MOVE)
             if not self.oem_user_config:
@@ -961,14 +967,15 @@ class Wizard(BaseFrontend):
 
     def lockdown_environment(self):
         atexit.register(self.unlock_environment)
-        for key in (
+        keys = (
             ('com.canonical.indicator.session', 'suppress-logout-menuitem'),
             ('com.canonical.indicator.session',
              'suppress-logout-restart-shutdown'),
             ('com.canonical.indicator.session', 'suppress-restart-menuitem'),
             ('com.canonical.indicator.session', 'suppress-shutdown-menuitem'),
             ('org.gnome.desktop.lockdown', 'disable-user-switching'),
-            ):
+        )
+        for key in keys:
             gs_schema = key[0]
             gs_key = key[1]
             gs_previous = '%s/%s' % (gs_schema, gs_key)
@@ -991,14 +998,15 @@ class Wizard(BaseFrontend):
 
     def unlock_environment(self):
         syslog.syslog('Reverting lockdown of the desktop environment.')
-        for key in (
+        keys = (
             ('com.canonical.indicator.session', 'suppress-logout-menuitem'),
             ('com.canonical.indicator.session',
              'suppress-logout-restart-shutdown'),
             ('com.canonical.indicator.session', 'suppress-restart-menuitem'),
             ('com.canonical.indicator.session', 'suppress-shutdown-menuitem'),
             ('org.gnome.desktop.lockdown', 'disable-user-switching'),
-            ):
+        )
+        for key in keys:
             gs_schema = key[0]
             gs_key = key[1]
             gs_previous = '%s/%s' % (gs_schema, gs_key)
@@ -1040,8 +1048,9 @@ class Wizard(BaseFrontend):
         core_names.append('ubiquity/text/update_installer_only')
         core_names.append('ubiquity/text/USB')
         core_names.append('ubiquity/text/CD')
-        for stock_item in ('cancel', 'close', 'go-back', 'go-forward',
-                            'ok', 'quit'):
+        stock_items = (
+            'cancel', 'close', 'go-back', 'go-forward', 'ok', 'quit')
+        for stock_item in stock_items:
             core_names.append('ubiquity/imported/%s' % stock_item)
         prefixes = []
         for p in self.pages:
@@ -1258,6 +1267,11 @@ class Wizard(BaseFrontend):
             self.allow_go_backward(False)
         elif 'UBIQUITY_AUTOMATIC' not in os.environ:
             self.allow_go_backward(True)
+
+        # If we are in oem-config, ensure the back button is displayed if
+        # and only if we are not on the first page.
+        if self.oem_user_config:
+            self.back.set_visible(self.pagesindex > 0)
         return True
 
     def set_page_title(self, page, lang=None):
@@ -1442,17 +1456,17 @@ class Wizard(BaseFrontend):
     # Callbacks provided to components.
 
     def watch_debconf_fd(self, from_debconf, process_input):
-        GObject.io_add_watch(from_debconf,
-                             GObject.IO_IN | GObject.IO_ERR | GObject.IO_HUP,
-                             self.watch_debconf_fd_helper, process_input)
+        GLib.io_add_watch(from_debconf,
+                          GLib.IO_IN | GLib.IO_ERR | GLib.IO_HUP,
+                          self.watch_debconf_fd_helper, process_input)
 
     def watch_debconf_fd_helper(self, source, cb_condition, callback):
         debconf_condition = 0
-        if (cb_condition & GObject.IO_IN) != 0:
+        if (cb_condition & GLib.IO_IN) != 0:
             debconf_condition |= filteredcommand.DEBCONF_IO_IN
-        if (cb_condition & GObject.IO_ERR) != 0:
+        if (cb_condition & GLib.IO_ERR) != 0:
             debconf_condition |= filteredcommand.DEBCONF_IO_ERR
-        if (cb_condition & GObject.IO_HUP) != 0:
+        if (cb_condition & GLib.IO_HUP) != 0:
             debconf_condition |= filteredcommand.DEBCONF_IO_HUP
 
         return callback(source, debconf_condition)
@@ -1700,21 +1714,19 @@ class Wizard(BaseFrontend):
                 text = option
             if text is None:
                 text = option
-            buttons.extend((text, len(buttons) / 2 + 1))
-        dialog = Gtk.Dialog(
-            title, self.live_installer, Gtk.DialogFlags.MODAL, tuple(buttons))
-        vbox = Gtk.Box()
-        vbox.set_orientation(Gtk.Orientation.VERTICAL)
-        vbox.set_border_width(5)
-        label = Gtk.Label(label=msg)
-        label.set_line_wrap(True)
-        label.set_selectable(False)
-        vbox.pack_start(label, True, True, 0)
-        vbox.show_all()
-        dialog.get_content_area().pack_start(vbox, True, True, 0)
-        response = dialog.run()
+            buttons.append((text, len(buttons) + 1))
+
+        self.ubi_question_dialog.set_title(title)
+        self.question_label.set_text(msg)
+        actions = self.ubi_question_dialog.get_action_area()
+        for action in actions.get_children():
+            actions.remove(action)
+        for text, response_id in buttons:
+            self.ubi_question_dialog.add_button(text, response_id)
+        self.ubi_question_dialog.show_all()
+        response = self.ubi_question_dialog.run()
         self.allow_change_step(saved_allowed_change_step)
-        dialog.hide()
+        self.ubi_question_dialog.hide()
         if response < 0:
             # something other than a button press, probably destroyed
             return None
@@ -1750,7 +1762,7 @@ class Wizard(BaseFrontend):
 
         def quit_quit():
             # Wait until we're actually out of this main loop
-            GObject.idle_add(idle_quit)
+            GLib.idle_add(idle_quit)
             return False
 
         if self.pending_quits == 0:
