@@ -91,7 +91,7 @@ class PageGtk(plugin.PluginUI):
     def calculate_clicked(self, *args):
         from ubiquity.frontend.gtk_components.keyboard_query import (
             KeyboardQuery,
-            )
+        )
         self.query = KeyboardQuery(self.controller._wizard)
         self.query.connect('layout_result', self.calculate_result)
         self.query.connect('delete-event', self.calculate_closed)
@@ -104,13 +104,13 @@ class PageGtk(plugin.PluginUI):
 
     @plugin.only_this_page
     def on_keyboard_layout_selected(self, *args):
-        if not 'UBIQUITY_AUTOMATIC' in os.environ:
+        if not self.is_automatic:
             # Let's not call this every time the user presses a key.
-            from gi.repository import GObject
+            from gi.repository import GLib
             if self.keyboard_layout_timeout_id:
-                GObject.source_remove(self.keyboard_layout_timeout_id)
-            self.keyboard_layout_timeout_id = GObject.timeout_add(600,
-                                            self.keyboard_layout_timeout)
+                GLib.source_remove(self.keyboard_layout_timeout_id)
+            self.keyboard_layout_timeout_id = GLib.timeout_add(
+                600, self.keyboard_layout_timeout)
         else:
             self.keyboard_layout_timeout()
 
@@ -126,13 +126,13 @@ class PageGtk(plugin.PluginUI):
 
     @plugin.only_this_page
     def on_keyboard_variant_selected(self, *args):
-        if not 'UBIQUITY_AUTOMATIC' in os.environ:
+        if not self.is_automatic:
             # Let's not call this every time the user presses a key.
-            from gi.repository import GObject
+            from gi.repository import GLib
             if self.keyboard_variant_timeout_id:
-                GObject.source_remove(self.keyboard_variant_timeout_id)
-            self.keyboard_variant_timeout_id = GObject.timeout_add(600,
-                                            self.keyboard_variant_timeout)
+                GLib.source_remove(self.keyboard_variant_timeout_id)
+            self.keyboard_variant_timeout_id = GLib.timeout_add(
+                600, self.keyboard_variant_timeout)
         else:
             self.keyboard_variant_timeout()
 
@@ -445,20 +445,20 @@ class Page(plugin.Plugin):
         command = [
             '/usr/lib/ubiquity/console-setup/keyboard-configuration.postinst',
             'configure',
-            ]
+        ]
         questions = [
             '^keyboard-configuration/layout',
             '^keyboard-configuration/variant',
             '^keyboard-configuration/model',
             '^keyboard-configuration/altgr$',
             '^keyboard-configuration/unsupported_',
-            ]
+        ]
         environ = {
             'OVERRIDE_ALLOW_PRESEEDING': '1',
             'OVERRIDE_USE_DEBCONF_LOCALE': '1',
             'LC_ALL': di_locale,
             'PATH': '/usr/lib/ubiquity/console-setup:' + os.environ['PATH'],
-            }
+        }
         return command, questions, environ
 
     # keyboard-configuration has a complex model of whether to store defaults
@@ -510,7 +510,7 @@ class Page(plugin.Plugin):
             # checked by hand. The seen flag on
             # keyboard-configuration/layout is used internally by
             # keyboard-configuration, so we can't just force it to true.
-            if ('UBIQUITY_AUTOMATIC' in os.environ and
+            if (self.is_automatic and
                 self.db.fget(
                     'keyboard-configuration/layoutcode', 'seen') == 'true'):
                 return True
@@ -622,8 +622,8 @@ class Page(plugin.Plugin):
         real_options = [opt for opt in options if not opt.startswith('lv3:')]
         if not latin:
             toggle = re.compile(r'^grp:.*toggle$')
-            real_options = [opt for opt in real_options
-                                if not toggle.match(opt)]
+            real_options = [
+                opt for opt in real_options if not toggle.match(opt)]
             # TODO cjwatson 2006-09-07: honour crazy preseeding; probably
             # not quite right, especially for Apples which may need a level
             # 3 shift
