@@ -19,7 +19,6 @@
 
 from __future__ import print_function
 
-from IN import INT_MAX
 import os
 import subprocess
 import sys
@@ -33,17 +32,6 @@ AFTER = 'language'
 WEIGHT = 11
 OEM = False
 
-JOCKEY = 'com.ubuntu.DeviceDriver'
-JOCKEY_PATH = '/DeviceDriver'
-
-# From dbus-python:
-#  if (timeout_s > ((double)INT_MAX) / 1000.0) {
-#     PyErr_SetString(PyExc_ValueError, "Timeout too long");
-#     return NULL;
-# }
-# timeout_ms = (int)(timeout_s * 1000.0);
-MAX_DBUS_TIMEOUT = INT_MAX / 1000.0
-
 
 # TODO: This cannot be a non-debconf plugin after all as OEMs may want to
 # preseed the 'install updates' and 'install non-free software' options.  So?
@@ -80,7 +68,7 @@ class PageGtk(PreparePageBase):
     restricted_package_name = 'ubuntu-restricted-addons'
 
     def __init__(self, controller, *args, **kwargs):
-        if 'UBIQUITY_AUTOMATIC' in os.environ:
+        if self.is_automatic:
             self.page = None
             return
         self.controller = controller
@@ -152,7 +140,7 @@ class PageKde(PreparePageBase):
 
     def __init__(self, controller, *args, **kwargs):
         from ubiquity.qtwidgets import StateBox
-        if 'UBIQUITY_AUTOMATIC' in os.environ:
+        if self.is_automatic:
             self.page = None
             return
         self.controller = controller
@@ -220,11 +208,12 @@ class PageKde(PreparePageBase):
         # it per plugin because our title widget is per plugin.  Also add
         # Bold here (not sure how the gtk side keeps that formatting).
         release = misc.get_release()
-        for widget in (
+        widgets = (
             self.page.prepare_heading_label,
             self.page.prepare_best_results,
             self.page.prepare_foss_disclaimer,
-            ):
+        )
+        for widget in widgets:
             text = widget.text()
             text = text.replace('${RELEASE}', release.name)
             text = text.replace('Ubuntu', 'Kubuntu')
@@ -235,7 +224,7 @@ class PageKde(PreparePageBase):
 class Page(plugin.Plugin):
     def prepare(self):
         if (self.db.get('apt-setup/restricted') == 'false' or
-            self.db.get('apt-setup/multiverse') == 'false'):
+                self.db.get('apt-setup/multiverse') == 'false'):
             self.ui.set_allow_nonfree(False)
         else:
             use_nonfree = self.db.get('ubiquity/use_nonfree') == 'true'
@@ -282,6 +271,7 @@ class Page(plugin.Plugin):
                 self.preseed_bool('apt-setup/universe', True)
                 self.preseed_bool('apt-setup/multiverse', True)
                 if self.db.fget('ubiquity/nonfree_package', 'seen') != 'true':
-                    self.preseed('ubiquity/nonfree_package',
+                    self.preseed(
+                        'ubiquity/nonfree_package',
                         self.ui.restricted_package_name)
         plugin.Plugin.ok_handler(self)
